@@ -1,4 +1,4 @@
-# $Id: Piece.pm 81 2009-05-09 02:31:43Z matt $
+# $Id: Piece.pm 90 2010-01-11 21:02:28Z matt $
 
 package Time::Piece;
 
@@ -9,7 +9,6 @@ require DynaLoader;
 use Time::Seconds;
 use Carp;
 use Time::Local;
-use UNIVERSAL qw(isa);
 
 our @ISA = qw(Exporter DynaLoader);
 
@@ -22,7 +21,7 @@ our %EXPORT_TAGS = (
     ':override' => 'internal',
     );
 
-our $VERSION = '1.14';
+our $VERSION = '1.16';
 
 bootstrap Time::Piece $VERSION;
 
@@ -78,7 +77,7 @@ sub new {
         $self = $class->localtime();
     }
     
-    return bless $self, $class;
+    return bless $self, ref($class) || $class;
 }
 
 sub parse {
@@ -102,7 +101,7 @@ sub _mktime {
            : $class;
     if (ref($time)) {
         $time->[c_epoch] = undef;
-        return wantarray ? @$time : bless [@$time, $islocal], $class;
+        return wantarray ? @$time : bless [@$time[0..9], $islocal], $class;
     }
     _tzset();
     my @time = $islocal ?
@@ -601,7 +600,12 @@ sub add_months {
     if ($final_month > 11 || $final_month < 0) {
         # these two ops required because we have no POSIX::floor and don't
         # want to load POSIX.pm
-        $num_years = int($final_month / 12);
+        if ($final_month < 0 && $final_month % 12 == 0) {
+            $num_years = int($final_month / 12) + 1;
+        }
+        else {
+            $num_years = int($final_month / 12);
+        }
         $num_years-- if ($final_month < 0);
         
         $final_month = $final_month % 12;
@@ -609,7 +613,7 @@ sub add_months {
     
     my @vals = _mini_mktime($time->sec, $time->min, $time->hour,
                             $time->mday, $final_month, $time->year - 1900 + $num_years);
-#    warn(sprintf("got vals: %d-%d-%d %d:%d:%d\n", reverse(@vals)));
+    # warn(sprintf("got %d vals: %d-%d-%d %d:%d:%d [%d]\n", scalar(@vals), reverse(@vals), $time->[c_islocal]));
     return scalar $time->_mktime(\@vals, $time->[c_islocal]);
 }
 
@@ -835,6 +839,20 @@ subsequently call that with the %Z formatting code. You must change $ENV{TZ}
 in the main thread to have the desired effect in this case (and you must
 also call _tzset() in the main thread to register the environment change).
 
+Furthermore, remember that this caveat also applies to fork(), which is
+emulated by threads on Win32.
+
+=head2 Use of epoch seconds
+
+This module internally uses the epoch seconds system that is provided via
+the perl C<time()> function and supported by C<gmtime()> and C<localtime()>.
+
+If your perl does not support times larger than C<2^31> seconds then this
+module is likely to fail at processing dates beyond the year 2038. There are
+moves afoot to fix that in perl. Alternatively use 64 bit perl. Or if none
+of those are options, use the L<DateTime> module which has support for years
+well into the future and past.
+
 =head1 AUTHOR
 
 Matt Sergeant, matt@sergeant.org
